<?php

namespace Drupal\exception_mailer;

use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Provides an interface defining an Exception Mailer Exclude entities entity.
 *
 * @ingroup exception_mailer
 */
interface ExceptionMailerExcludeInterface extends ConfigEntityInterface {

  /**
   * Returns the exclude description.
   *
   * @return string
   *   The exclude description.
   */
  public function getDescription();

  /**
   * Returns the exclude type.
   *
   * @return string
   *   The exclude type: error/exception.
   */
  public function getType();

  /**
   * Returns the exception contains string.
   *
   * @return string
   *   The exception.
   */
  public function getException();

  /**
   * Returns the error type.
   *
   * @return string
   *   The error type, e.g. php.
   */
  public function getErrorType();

  /**
   * Returns array with error severity codes.
   *
   * @return array
   *   The error severity code: notice/warning/etc.
   */
  public function getErrorSeverity();

  /**
   * Returns the exception/error message contains string.
   *
   * @return string
   *   The exception/error message.
   */
  public function getMessage();

  /**
   * Returns the hostname contains string.
   *
   * @return string
   *   The hostname.
   */
  public function getHostname();

  /**
   * Returns the send_email property.
   *
   * @return bool
   *   True if email should be sent.
   */
  public function getSendEmail();

  /**
   * Returns the email addresses or empty array.
   *
   * @return array
   *   Email addresses.
   */
  public function getEmails();

  /**
   * Set email addresses.
   *
   * @param array $emails
   *   Email addresses.
   */
  public function setEmails(array $emails);

  /**
   * Returns the email body to be send.
   *
   * @return string
   *   Text of the email.
   */
  public function getEmailBody();

  /**
   * Returns the array of roles.
   *
   * @return array
   *   Roles.
   */
  public function getRoles();

  /**
   * Check data and return excludes.
   *
   * @return array
   *   Array of email addresses.
   */
  public function getEmailAddresses();

  /**
   * Returns the send interval in minutes.
   *
   * @return string
   *   The send interval.
   */
  public function getSendInterval();

  /**
   * Returns the timestamp of the last sent.
   *
   * @return int
   *   Timestamp.
   */
  public function getLastSent();

  /**
   * Returns the status.
   *
   * @return bool
   *   True on active.
   */
  public function getStatus();

}
