<?php

namespace Drupal\exception_mailer\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Logger\RfcLogLevel;
use Drupal\user\RoleInterface;

/**
 * Class ExceptionMailerConfigForm.
 */
class ExceptionMailerConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'exception_mailer.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'exception_mailer_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('exception_mailer.settings');
    $form['level_type'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Check the level type'),
      '#options' => RfcLogLevel::getLevels(),
      '#default_value' => $config->get('level_type'),
    ];

    $roles = user_role_names(TRUE);
    unset($roles[RoleInterface::AUTHENTICATED_ID]);
    $form['roles'] = [
      '#type' => 'select',
      '#title' => $this->t('Roles'),
      '#description' => $this->t('Email will be sent for users assigned to select role(s).'),
      '#options' => $roles,
      '#size' => min(count($roles), 8),
      '#multiple' => TRUE,
      '#default_value' => $config->get('roles'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('exception_mailer.settings')
      ->set('level_type', array_filter($form_state->getValue('level_type'), function ($v) {
        return $v !== 0;
      }))
      ->set('roles', $form_state->getValue('roles'))
      ->save();
  }

}
